==> qt-creator-2.2.0-src.zip: qt-creator-2.2.0-src/doc/pluginhowto/examples/wizard/itemmodelwizard/modelnamepage.cpp <==
/***************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (info@qt.nokia.com)
**
** This file is part of the documentation of Qt Creator.
**
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
****************************************************************************/

#include "modelnamepage.h"
#include "ui_modelnamepage.h"

ModelNamePage::ModelNamePage(QWidget *parent) :
QWizardPage(parent)
{
    setTitle("Enter model class information");
    setSubTitle("The header and source file names will be derived from the class name");
    ui.setupUi(this);
}

ModelNamePage::~ModelNamePage()
{

}

void ModelNamePage::setPath(const QString& path)
{
    this->path = path;
}

void ModelNamePage::on_txtModelClass_textEdited(const QString& txt)
{
    ui.txtHeaderFile->setText(txt + ".h");
    ui.txtImplFile->setText(txt + ".cpp");
}

ModelClassParameters ModelNamePage::parameters() const
{
    ModelClassParameters params;
    params.className = ui.txtModelClass->text();
    params.headerFile = ui.txtHeaderFile->text();

    params.sourceFile = ui.txtImplFile->text();
    params.baseClass = ui.cmbBaseClass->currentText();
    params.path = path;
    return params;
}

==> qt-creator-2.3.0-rc-src.zip: qt-creator-2.3.0-rc-src/doc/pluginhowto/examples/wizard/itemmodelwizard/modelnamepage.cpp <==
/***************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (info@qt.nokia.com)
**
** This file is part of the documentation of Qt Creator.
**
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
****************************************************************************/

#include "modelnamepage.h"

ModelNamePage::ModelNamePage(QWidget *parent)
    : QWizardPage(parent)
{
    setTitle("Enter model class information");
    setSubTitle("The header and source file names will be derived from the class name");
    ui.setupUi(this);
}

void ModelNamePage::setPath(const QString &path)
{
    this->path = path;
}

void ModelNamePage::on_txtModelClass_textEdited(const QString &text)
{
    ui.txtHeaderFile->setText(text + ".h");
    ui.txtImplFile->setText(text + ".cpp");
}

ModelClassParameters ModelNamePage::parameters() const
{
    ModelClassParameters params;
    params.className = ui.txtModelClass->text();
    params.headerFile = ui.txtHeaderFile->text();

    params.sourceFile = ui.txtImplFile->text();
    params.baseClass = ui.cmbBaseClass->currentText();
    params.path = path;
    return params;
}
